@@ -54,35 +54,25 @@ void ComicData::storePosition(bool store)
     save();
 }
 
-void ComicData::setData(const Plasma::DataEngine::Data &data)
+void ComicData::setData(const ComicMetaData &data)
 {
-    const bool hasError = data[QStringLiteral("Error")].toBool();
-    if (!hasError) {
-        mImage = data[QStringLiteral("Image")].value<QImage>();
-        mPrev = data[QStringLiteral("Previous identifier suffix")].toString();
-        mNext = data[QStringLiteral("Next identifier suffix")].toString();
-        mAdditionalText = data[QStringLiteral("Additional text")].toString();
-        mReady = true;
+    if (!data.error) {
+        mImage = data.image;
+        mPrev = data.previousIdentifier;
+        mNext = data.nextIdentifier;
+        mAdditionalText = data.additionalText;
     }
 
-    mWebsiteUrl = data[QStringLiteral("Website Url")].toUrl();
-    mImageUrl = data[QStringLiteral("Image Url")].toUrl();
-    mShopUrl = data[QStringLiteral("Shop Url")].toUrl();
-    mFirst = data[QStringLiteral("First strip identifier suffix")].toString();
-    mStripTitle = data[QStringLiteral("Strip title")].toString();
-    mAuthor = data[QStringLiteral("Comic Author")].toString();
-    mTitle = data[QStringLiteral("Title")].toString();
+    mWebsiteUrl = data.websiteUrl;
+    mImageUrl = data.imageUrl;
+    mShopUrl = data.shopUrl;
+    mFirst = data.firstStripIdentifier;
+    mStripTitle = data.stripTitle;
+    mAuthor = data.comicAuthor;
+    mTitle = data.providerName;
+    mType = data.identifierType;
 
-    const QString suffixType = data[QStringLiteral("SuffixType")].toString();
-    if (suffixType == QLatin1String("Date")) {
-        mType = Date;
-    } else if (suffixType == QLatin1String("Number")) {
-        mType = Number;
-    } else {
-        mType = String;
-    }
-
-    QString temp = data[QStringLiteral("Identifier")].toString();
+    QString temp = data.identifier;
     mCurrent = temp.remove(mId + QLatin1Char(':'));
 
     // found a new last identifier
@@ -91,7 +81,7 @@ void ComicData::setData(const Plasma::DataEngine::Data &data)
     }
 
     mCurrentReadable.clear();
-    if (mType == Number) {
+    if (mType == IdentifierType::NumberIdentifier) {
         mCurrentReadable = i18nc("an abbreviation for Number", "# %1", mCurrent);
         int tempNum = mCurrent.toInt();
         if (mMaxStripNum < tempNum) {
@@ -100,19 +90,19 @@ void ComicData::setData(const Plasma::DataEngine::Data &data)
 
         temp = mFirst.remove(mId + QLatin1Char(':'));
         mFirstStripNum = temp.toInt();
-    } else if (mType == Date && QDate::fromString(temp, QStringLiteral("yyyy-MM-dd")).isValid()) {
+    } else if (mType == IdentifierType::DateIdentifier && QDate::fromString(temp, QStringLiteral("yyyy-MM-dd")).isValid()) {
         mCurrentReadable = mCurrent;
-    } else if (mType == String) {
+    } else if (mType == IdentifierType::StringIdentifier) {
         mCurrentReadable = mCurrent;
     }
 
-    mIsLeftToRight = data[QStringLiteral("isLeftToRight")].toBool();
-    mIsTopToBottom = data[QStringLiteral("isTopToBottom")].toBool();
+    mIsLeftToRight = data.isLeftToRight;
+    mIsTopToBottom = data.isTopToBottom;
 
     save();
 }
 
-void ComicData::createErrorPicture(const Plasma::DataEngine::Data &data)
+void ComicData::createErrorPicture(const QVariantMap &data)
 {
     QPixmap errorPic(500, 400);
     errorPic.fill();
